transition property
The transition used to animate a moved child back to its new position.
Defaults to NibTransition.springGentle.
Implementation
final NibTransition? transition;
The transition used to animate a moved child back to its new position.
Defaults to NibTransition.springGentle.
final NibTransition? transition;