NibScrollMotion class

Creates a ScrollMotionBridge for controller and exposes it to builder, disposing it when this widget is removed.

NibScrollMotion(
  controller: myScrollController,
  builder: (context, bridge) => NibMotion(
    motionValues: NibMotionValues(
      opacity: bridge.scrollY.mapRange([0, 200], [1.0, 0.0]),
    ),
    child: MyWidget(),
  ),
)
Inheritance
Available extensions

Constructors

NibScrollMotion({Key? key, required ScrollController controller, required Widget builder(BuildContext context, ScrollMotionBridge bridge)})
Creates a NibScrollMotion.
const

Properties

builder Widget Function(BuildContext context, ScrollMotionBridge bridge)
Builds the subtree below this widget, given the ScrollMotionBridge created for controller.
final
controller ScrollController
The scroll controller whose offset is mirrored into the ScrollMotionBridge passed to builder.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

animate({Object? initial, Object? animate, NibAnim? exit, NibTransition? transition, NibAnim? whileTap, NibAnim? whileHover, Key? key}) Widget

Available on Widget, provided by the NibMotionWidgetExtension extension

Wraps this widget in a NibMotion.
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<NibScrollMotion>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revealOnScroll({NibAnim? initial, bool once = true}) Widget

Available on Widget, provided by the NibMotionWidgetExtension extension

Wraps this widget in a NibScrollReveal.
shimmer({bool enabled = true}) Widget

Available on Widget, provided by the NibMotionWidgetExtension extension

Wraps this widget in a NibShimmer.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited