builder property
Builds the subtree below this widget, given the ScrollMotionBridge created for controller.
Implementation
final Widget Function(BuildContext context, ScrollMotionBridge bridge)
builder;
Builds the subtree below this widget, given the ScrollMotionBridge created for controller.
final Widget Function(BuildContext context, ScrollMotionBridge bridge)
builder;