NibTextRevealDirection enum

The edge from which a NibTextReveal wipes its child into view.

Inheritance
Available extensions

Values

left → const NibTextRevealDirection

Reveals left-to-right, clipping from the left edge.

Reveals right-to-left, clipping from the right edge.

up → const NibTextRevealDirection

Reveals bottom-to-top, clipping from the top edge.

down → const NibTextRevealDirection

Reveals top-to-bottom, clipping from the bottom edge.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NibTextRevealDirection>
A constant List of the values in this enum, in order of their declaration.