NibTextUnit enum
The granularity at which NibText splits its text into animated units.
Values
- character → const NibTextUnit
-
Each grapheme cluster (user-perceived character, including multi-code-unit emoji) is its own animated unit.
- word → const NibTextUnit
-
Each whitespace-delimited word is its own animated unit. Runs of whitespace between words are preserved as plain (non-animated) text.
- line → const NibTextUnit
-
Each line (split on
\n) is its own animated unit.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
NibTextUnit> - A constant List of the values in this enum, in order of their declaration.